.. kua documentation master file, created by
   sphinx-quickstart on Sat Aug 27 14:46:31 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

kua's docs
==========

User’s Guide
------------

.. toctree::
   :maxdepth: 2

   installation
   usage
   recipes
   limitations

API Reference
-------------

Information on a specific function, class or method.

.. toctree::
   :maxdepth: 2

   api

Additional Notes
----------------

Design notes, legal information and changelog.

.. toctree::
   :maxdepth: 2

   changelog
   license

